#!/bin/bash
#
# PrivX Extender post install script.
#
# Run after installing the rpm package.
#

# Parse arguments
for arg in "$@"
do
  case $arg in
    --log-to-file)
    logfile=/var/log/privx-install.log
    exec 3>&1 1>>${logfile} 2>&1
    echo "-----"
    echo "PrivX Extender install "`date`
    echo
    ;;

    --request-cert)
    request_cert="yes"
    ;;

    *)
    echo "unknown argument $arg"
    exit 1
    ;;
  esac
done

# Check if need to skip automatic postinstall
case $SKIP_POSTINSTALL in
true|TRUE|1)
  echo
  echo "Skipping automatic post installation steps"
  echo
  echo "Please make sure to run the /opt/privx/scripts/extender-postinstall.sh manually."
  echo
  exit 0
  ;;
*)
  ;;
esac

# Check that configuration file exists
echo "Checking extender configuration file:"
extenderconfig="/opt/privx/etc/extender-config.toml"
if [ ! -r "$extenderconfig" ]
then
  echo "$extenderconfig missing."
  echo
  echo "Download extender configuration from PrivX UI,"
  echo "copy it to $extenderconfig"
  echo "and re-run /opt/privx/scripts/extender-postinstall.sh"
  echo
  exit 0
fi
echo "done"

if ! grep -q privx_ssh_mitm "$extenderconfig"
then
  echo "$extenderconfig needs upgrade."
  echo
  echo "Download extender configuration from PrivX UI,"
  echo "copy it to $extenderconfig"
  echo "and re-run /opt/privx/scripts/extender-postinstall.sh"
  echo
  exit 1
fi

# Remove all permissions from other to keep credentials safe
chown root:privx $extenderconfig
chmod 0640 $extenderconfig
echo "done"


# Stop extender
echo "Checking extender status:"
if systemctl is-active privx-extender
then
  echo "Stopping extender:"
  systemctl stop privx-extender
  echo "done"
fi

# Register extender to server
echo "Registering extender:"

if [ -n "$request_cert" ]
then
  # Move existing cert and private key to request a new cert
  certfile=`sed -n 's;certificate_file\s*=\s*"\(.*\)";\1;p' $extenderconfig`
  keyfile=`sed -n 's;private_key_file\s*=\s*"\(.*\)";\1;p' $extenderconfig`
  if [ -e "$certfile" ]; then mv -f "$certfile" "$certfile.bak"; fi
  if [ -e "$keyfile" ]; then mv -f "$keyfile" "$keyfile.bak"; fi
fi

su privx -c "/opt/privx/bin/privx-extender -register"
status=$?

if [ $status -ne 0 ]
then
  if [ -e "$certfile.bak" ]; then mv -f "$certfile.bak" "$certfile"; fi
  if [ -e "$keyfile.bak" ]; then mv -f "$keyfile.bak" "$keyfile"; fi

  echo "Registration failed."
  echo "Check the following:"
  echo "  - Configuration in $extenderconfig is correct"
  echo "  - PrivX server is reachable"
  echo "  - Extender is not already registered in PrivX UI"
  echo "Re-run /opt/privx/scripts/extender-postinstall.sh after fixing the problem."
  echo
  exit $status
fi
rm -f "$certfile.bak" "$keyfile.bak"
echo "done"

# Enable PrivX Extender
echo "Enabling privx-extender:"
chkconfig privx-extender on
systemctl enable privx-extender
echo "done"

# Start PrivX Extender
echo "Starting privx-extender:"
systemctl restart privx-extender
echo "done"

exit 0
