#!/bin/sh
### BEGIN INIT INFO
# Provides:          privx-extender
# Required-Start:    $remote_fs $syslog
# Required-Stop:     $remote_fs $syslog
# Default-Start:     2 3 4 5
# Default-Stop:      0 1 6
# Short-Description: Start daemon at boot time
# Description:       PrivX Extender
### END INIT INFO

dir="/opt/privx/bin"
cmd="SSH_LOG_LEVEL=INFO SSH_TRACE=0 /opt/privx/bin/privx-extender -run"
user="privx"
watchdog="/opt/privx/scripts/watchdog.sh privx-extender"

name=`basename $0 .sh`
pid_file="/var/run/privx-$name.pid"
watchdog_pid_file="/var/run/privx-watchdog-$name.pid"
stdout_log="/var/log/privx/$name.log"
stderr_log="/var/log/privx/$name.log"

get_pid() {
    cat "$pid_file"
}

is_running() {
    [ -f "$pid_file" ] && ps `get_pid` > /dev/null 2>&1
}

case "$1" in
    start)
    if is_running; then
        echo "Already started"
    else
        echo "Starting $name"
        cd "$dir"
        if [ -z "$user" ]; then
            sudo $cmd >> "$stdout_log" 2>> "$stderr_log" &
        else
            sudo -u "$user" $cmd >> "$stdout_log" 2>> "$stderr_log" &
        fi
        echo $! > "$pid_file"
        if ! is_running; then
            echo "Unable to start, see $stdout_log and $stderr_log"
            exit 1
        fi
        $watchdog &
        echo $! > $watchdog_pid_file
    fi
    ;;
    stop)
    if is_running; then
        
        echo -n "Stopping watchdog for $name.."
        if [ -f "$watchdog_pid_file" ]; then
            kill -9 `cat $watchdog_pid_file`
            rm "$watchdog_pid_file"
        fi

        echo -n "Stopping $name.."
        kill `get_pid`
        for i in {1..10}
        do
            if ! is_running; then
                break
            fi

            echo -n "."
            sleep 1
        done
        echo

        if [ -f "$pid_file" ]; then
            rm "$pid_file"
        fi

        if is_running; then
            echo "Not stopped; may still be shutting down or shutdown may have failed"
            exit 1
        else
            echo "Stopped"
        fi
    else
        echo "Not running"
    fi
    ;;
    restart)
    $0 stop
    if is_running; then
        echo "Unable to stop, will not attempt to start"
        exit 1
    fi
    $0 start
    ;;
    status)
    if is_running; then
        echo "Running"
    else
        echo "Stopped"
        exit 1
    fi
    ;;
    *)
    echo "Usage: $0 {start|stop|restart|status}"
    exit 1
    ;;
esac

exit 0
