#!/bin/bash
# Monitors PrivX service. If the service has died, restart it.

REQUIRED_SERVICE="$@"
LOGFILE=/var/log/privx/watchdog.log
PIDFILE=/var/run/privx-${REQUIRED_SERVICE}.pid

if [ "$REQUIRED_SERVICE" == "" ]
then
  echo "Missing service name"
  exit 1
fi

echo "`date` INFO: Watchdog started, watching service: ${REQUIRED_SERVICE}" | tee -a $LOGFILE

end=0
while [[ $end == 0 ]]
do
  if [ ! -f $PIDFILE ]
  then
        echo "`date` PID file not found, ${REQUIRED_SERVICE} service might not be running. Exiting watchdog." | tee -a $LOGFILE
        exit
  fi

  PID=`cat $PIDFILE`
  while [ -e /proc/$PID ]
  do
      sleep 1
  done
  EXITED=`service ${REQUIRED_SERVICE} status | grep "Active: active (exited)"`

  if [[ "$EXITED" != "" ]]
  then
    tail -n 1000 /var/log/privx/${REQUIRED_SERVICE}.log | grep -i panic -B 3 -A 30 >> $LOGFILE
    echo "`date` Service ${REQUIRED_SERVICE} exited, restarting." | tee -a $LOGFILE
    systemctl restart ${REQUIRED_SERVICE}
  fi
sleep 10
done
